%
function f=periodg(x,win)
%
%
%        This function computes the periodogram.  
%        win=0, no window is applied (nonsmoothed periodogram).
%        win=1, the Blackman-Tukey window is applied.
%        win=2, the Parzen window is applied.
%        win=3, the Tukey-Hanning window is applied.
%        the ordinary periodogram is computed.
%
%
% Copyright (c) 21 July 2003 by Victor Gomez
% Ministerio de Hacienda, Direccion Gral. de Presupuestos, 
% Subdireccion Gral. de Analisis y P.E., 
% Alberto Alcocer 2, 1-P, D-34, 28046, Madrid, SPAIN.
% Phone : +34-915835439
% E-mail: vgomez@sepg.minhac.es
%
% The author assumes no responsibility for errors or damage resulting from the use
% of this code. Usage of this code in applications and/or alterations of it should 
% be referenced. This code may be redistributed if nothing has been added or
% removed and no money is charged. Positive or negative feedback would be appreciated.
%
n=length(x);
cxx0=croscov(x,x,0);
np=floor((n-1)/2);
if win >= 1
   f=zeros(1,np+1);
   if win == 1
      [w,m]=blacktu(n);
   elseif win == 2
      [w,m]=parzen(n);
   elseif win == 3
      [w,m]=tukhan(n);
   end
   cxx=zeros(1,m);
   for i=1:m
      cxx(i)=croscov(x,x,i);
   end
   for i=1:np
      aux=0;
      for j=1:m
         aux=aux+w(j)*cxx(j)*cos(2*pi*j*i/n);
      end
      f(i+1)=cxx0/(2*pi)+aux/pi;
    end
    aux=cxx*w;
    f(1)=cxx0/(2*pi)+aux/pi;
else
   f=zeros(1,np+1);
   m=n-1;
   cxx=zeros(1,m);
   for i=1:m
      cxx(i)=croscov(x,x,i);
   end
   for i=1:np
      aux=0;
      for j=1:m
         aux=aux+cxx(j)*cos(2*pi*j*i/n);
      end
      f(i+1)=cxx0/(2*pi)+aux/pi;
    end
    f(1)=(n/(2*pi))*(mean(x))^2;
end
