function pforcst(out,cw)
%
% MATLAB program to plot the forecasts obtained with TS
%
% Input parameters: 
%   out: a structure containing the output of TS or TST
%    cw: parameter for the with of confidence intervals, for example 1.96
%
% Copyright (c) November 2009 by Victor Gomez
% Ministerio de Hacienda, Direccion Gral. de Presupuestos, 
% Subdireccion Gral. de Analisis y P.E., 
% Alberto Alcocer 2, 1-P, D-34, 28046, Madrid, SPAIN.
% Phone : +34-915835439
% E-mail: vgomez@sepg.minhac.es
%
% The author assumes no responsibility for errors or damage resulting from the use
% of this code. Usage of this code in applications and/or alterations of it should 
% be referenced. This code may be redistributed if nothing has been added or
% removed and no money is charged. Positive or negative feedback would be appreciated.
%


if nargin < 2
 cw=1.96;
end

fname=out.title;
lam=out.model.lamda;
s=out.model.freq;
yor=out.orig; 


fforcst=0;
if isfield(out,'forecast')
%plot forecasts  
 yy=out.forecast.pred; [nyy,myy]=size(yy);
 fforcst=1;
elseif isfield(out,'ftx')
 yy=out.ftx; [nyy,myy]=size(yy);
 fforcst=1;
end
if fforcst == 1
 npr=floor(nyy/2);
 y1=yy(:,1); 
 spry=yy(npr+2:end,2); pry=yy(npr+2:end,1); 
 opry=pry; ospry=spry;
 if lam == 0
  y1(1:npr+1)=log(y1(1:npr+1));
  opry=yy(npr+2:end,3);
  for i=1:npr
   ospry(i)=exp(double(2.)*pry(i)+spry(i)^2)*(exp(spry(i)^2)-double(1.));
  end
 end
 y2=[y1(1:npr+1); pry + cw*spry];
 y3=[y1(1:npr+1); pry - cw*spry];
 figure
 t=-npr:npr;  
 vnames=['Upper band', 
         'Forecast  ', 
         'Lower band'];
 plot(t,y1,'r-',t,y2,'-.',t,y3,'--'); legend(vnames);
 set(gca,'tickdir','in');        set(gca,'xcolor','k');
 set(gca,'GridLineStyle',':');   set(gca,'Xgrid','on'); 
%    axis tight;  
 if lam == 0
  title(['Forecasts of series ' fname ' (in logs)'])
  disp('press any key to continue'); pause;
  figure
  y1=yy(:,3);     
  y2=[y1(1:npr+1); opry + cw*sqrt(ospry)];
  y3=[y1(1:npr+1); opry - cw*sqrt(ospry)];
  t=-npr:npr;
  vnames=['Upper band', 
          'Forecast  ', 
          'Lower band'];
  plot(t,y1,'r-',t,y2,'-.',t,y3,'--'); legend(vnames);
  set(gca,'tickdir','in');       set(gca,'xcolor','k');
  set(gca,'GridLineStyle',':');  set(gca,'Xgrid','on'); 
%    axis tight;
  title(['Forecasts of series ' fname])
 else
  title(['Forecasts of series ' fname])
 end
 disp('press any key to continue'); pause;
 if (s > 1)
%plot forecasts in rates of grothw
 figure
   yt=tasa([yor; opry],s)*100;  nyt=length(yt); 
   tt=nyt-2*npr:nyt;
   t=-npr:npr;
   plot(t,yt(tt),'r-');
   set(gca,'tickdir','in');       set(gca,'xcolor','k');
   set(gca,'GridLineStyle',':');  set(gca,'Xgrid','on'); 
%     axis tight;
   title(['Forecasts of original series ' fname, ' (rates of growth in percentage)'])
 end
else
 disp('no forecasts in structure out')
 return
end

