function infr = residcp(out,lag,cw,pflag)
%
% MATLAB program to analyze a residuals series obtained with TS
%
% Input parameters: 
%   out: a structure containing the output of TS or TST
%   lag: number of lags for the correlograms
%    cw: parameter for the with of confidence intervals, for example 1.96
% pflag: flag for graphics, 1 plot graphics, 0 no plots
%
%
% Copyright (c) November 2009 by Victor Gomez
% Ministerio de Hacienda, Direccion Gral. de Presupuestos, 
% Subdireccion Gral. de Analisis y P.E., 
% Alberto Alcocer 2, 1-P, D-34, 28046, Madrid, SPAIN.
% Phone : +34-915835439
% E-mail: vgomez@sepg.minhac.es
%
% The author assumes no responsibility for errors or damage resulting from the use
% of this code. Usage of this code in applications and/or alterations of it should 
% be referenced. This code may be redistributed if nothing has been added or
% removed and no money is charged. Positive or negative feedback would be appreciated.
%

infr=[];
if nargin < 3
 pflag=0;
end

e=out.series.residt;
conp=0; sconp=0;
p=out.model.p;
d=out.model.d;
q=out.model.q;
P=out.model.bp;
D=out.model.bd;
Q=out.model.bq;
nr=p+q+P+Q;
nreg=0; ireg=0;
if isfield(out,'ireg')
 ireg=out.model.ireg;
 nreg=nreg+ireg;
end
if isfield(out.model,'nao')
 nao=out.model.nao;
else
 nao=0;
end
if isfield(out.model,'ntc')
 ntc=out.model.ntc;
else
 ntc=0;
end
if isfield(out.model,'nls')
 nls=out.model.nls;
else
 nls=0;
end
nrout=nao+ntc+nls;
% nreg=nreg+out.model.imean;
nreg=nreg+out.model.itrad;
nreg=nreg+out.model.ieast;
nreg=nreg+nrout;
ndrs=out.nziyip(1) - d - D*out.model.freq;

Ss=e'*e; 
Ff=Ss; %this is an approximation to the nonlinear sum of squares.

infr = rescomp(e,lag,nr,Ss,conp,sconp,Ff,ndrs,nreg);

if pflag == 1
 yor=out.orig; 
 if isfield(out.series,'xlin')
  ycor=out.series.xlin;
 elseif isfield(out.series,'xint')
  ycor=out.series.xint;
 end
 datei=makedatei(out);
 fname=out.title;
 s=out.model.freq;
  figure                       %original and corrected series
 if (s == 12) | (s == 4)
  vnames=['Original series '
          'Corrected series'];
  tsplot([yor ycor],datei,vnames)
 else
  [nyor,myor]=size(yor); t=1:nyor;
  plot(t,yor,t,ycor); legend(fname,'Corrected series');
 end
 if pflag == 1, disp('strike any key when ready'); pause; end

% Youtg     %outlier effets
% Yrg       %regression effects other than outliers
% Y         %regression variables
% g         %regression estimates
 if nrout > 0
  figure;                                       %produce graph of outlier effects
  Youtg=out.regoutse.outsum;
  Yrg=out.regoutse.totrose-Youtg;
  plot(Youtg);  
  title('Sum of outlier effects');   
  if pflag == 1
      disp('strike any key when ready')
   pause
  end
  nreg=nreg-nrout;
 else
  if isfield(out,'regoutse')
   Yrg=out.regoutse.totrose;
  end
 end
 
 if nreg > 0
  figure;                                       %produce graph of regression effects other than outliers
  plot(Yrg);  
  title('Sum of regression effects other than outliers'); %hold off;
  if pflag == 1
      disp('strike any key when ready')
   pause
  end
 end

 figure
 ne=infr.ne; stde=infr.stde;
 t=1:ne; bd=ones(ne,1)*(cw*stde);                 %confidence bands
 plot(t,e,t,zeros(ne,1),t,bd,'r',t,-bd,'r')       %plot residuals
 legend('Residuals')
 if pflag == 1
     disp('strike any key when ready')
     pause
 end

 figure
 no=infr.no; xo=infr.xo;
 bar(xo,no);
 title('Residual histogram')
 xlabel('Standard deviation intervals')
 if pflag == 1
     disp('strike any key when ready')
     pause
 end


 figure
 fname='residuals';
 sea=infr.sea; sep=infr.sep; r=infr.r; pc=infr.pc;
 rpplot(r,pc,sea,sep,cw,fname);                  %plot residual autocorrelations
 if pflag == 1
     disp('strike any key when ready')
     pause
 end


 figure
 fname='squared residuals';
 rs=infr.rs; pcs=infr.pcs; seas=infr.seas;
 rpplot(rs,pcs,seas,sep,cw,fname);                            %plot autocorrelations
 if pflag == 1
     disp('strike any key when ready')
     pause
 end
end
