function spectran(win,corlag,graph,per,lpath,ppath)  
%
% Spectral analysis
%
% This programa computes the spectrum, coherence, phase delay, gain and
% cross correlations between a reference cycle and other cycles.
% 
% window
%        win=0, no window is applied (nonsmoothed periodogram).
%        win=1, the Blackman-Tukey window is applied.
%        win=2, the Parzen window is applied.
%        win=3, the Tukey-Hanning window is applied.
%
% the Parzen window seems to give the best results in practice
%
%
% Copyright (c) 21 July 2003 by Victor Gomez
% Ministerio de Hacienda, Direccion Gral. de Presupuestos, 
% Subdireccion Gral. de Analisis y P.E., 
% Alberto Alcocer 2, 1-P, D-34, 28046, Madrid, SPAIN.
% Phone : +34-915835439
% E-mail: vgomez@sepg.minhac.es
%
% The author assumes no responsibility for errors or damage resulting from the use
% of this code. Usage of this code in applications and/or alterations of it should 
% be referenced. This code may be redistributed if nothing has been added or
% removed and no money is charged. Positive or negative feedback would be appreciated.
%
%fid=fopen('param.spa');
%p=fscanf(fid,'%g',inf) 
%fclose(fid);
%win=p(1);                              % win selects the window
%corlag=p(2);                           % corlag selects the number of +/- correlations
%graph=p(3);                            % graph selects graphs
%per=p(4);                              % per is the series frequency (12 for monthly, etc.)


%
% open file containing the path to the different cycles.
% The first path corresponds to the reference cycle
fid=fopen(lpath);
% read path 
fname=fgetl(fid);
if ~ischar(fname)
 error('the path to the reference cycle is incorrect')
end
mm=length(fname); pos=0;
for i=mm:-1:1
 if fname(i)=='\',  pos=i;  break,   end
end
rfname=fname(pos+1:mm-4);
% read variables in file. There are two columns in it, the second column is the cycle.
fidd=fopen(fname);
s=fscanf(fidd,'%g %g',[2 inf]);  s=s';
fclose(fidd);
refc=s(:,2);

count=0; 
while 1
 fname=fgetl(fid);
 if ~ischar(fname)
% end of file encountered  
  disp('number of series processed:'); disp(count)
  break
 else
  count=count+1;  
  fidd=fopen(fname);
  s=fscanf(fidd,'%g %g',[2 inf]);  s=s';
  fclose(fidd);
  comc=s(:,2);  mm=length(fname);  pos=0;
  for i=mm:-1:1
   if fname(i)=='\',  pos=i;  break,   end
  end
  rname=fname(pos+1:mm-4);
  [copb,phpb,gapb,fxpb,fypb,frq]=crosspan(refc,comc,win);
  fid2=fopen([ppath '\spectan\' rname '.spa'],'w');
  apb=[frq';copb;phpb;gapb;fxpb;fypb];
  fprintf(fid2,'%15.8f%15.8f%15.8f%15.8f%15.8f%15.8f\n',apb);
  fclose(fid2);
  if graph == 1
   cc=ones(100,2); 
   cc(:,1)=cc(:,1)*((2*pi)/(per*1.5)); cc(:,2)=cc(:,2)*((2*pi)/(per*8)); 
   ll=(max(fxpb)-min(fxpb))/99; dd=min(fxpb):ll:max(fxpb);
   figure
   plot(frq,fxpb,cc(:,1),dd,cc(:,2),dd)
   legend(['spectrum ' rfname])
   pause 
   ll=(max(fypb)-min(fypb))/99; dd=min(fypb):ll:max(fypb);
   figure
   plot(frq,fypb,cc(:,1),dd,cc(:,2),dd)
   legend(['spectrum ' rname])
   pause 
   ll=(max(copb)-min(copb))/99; dd=min(copb):ll:max(copb);
   figure
   plot(frq,copb,cc(:,1),dd,cc(:,2),dd)
   legend(['coherence ' rfname '-' rname])
   pause 
   ll=(max(phpb)-min(phpb))/99; dd=min(phpb):ll:max(phpb);
   figure
   plot(frq,phpb,cc(:,1),dd,cc(:,2),dd)
   legend(['phase delay ' rfname '-' rname])
   pause 
  end
  cr=zeros(2*corlag,1);
  ind=-corlag+1:corlag;
  for i=-corlag+1:corlag
    [cro,stdx,stdy]=croscor(refc,comc,i);
    cr(corlag+i)=cro;
  end
  fid3=fopen([ppath '\spectan\' rname '.cor'],'w');
  fprintf(fid3,'   cross correlations: t =%3i to%3i   ',[-corlag+1 corlag]);
  for i=1:ceil(corlag/4)
   fprintf(fid3,'\n%7i%7i%7i%7i%7i%7i%7i%7i ',ind(8*(i-1)+1:min(8*i,2*corlag)));
   fprintf(fid3,'\n%7.3f%7.3f%7.3f%7.3f%7.3f%7.3f%7.3f%7.3f',cr(8*(i-1)+1:min(8*i,2*corlag)));
  end
  [mx,j]=max(abs(cr));
  fprintf(fid3,'\n   maximum correlation at t =%3i',ind(j)); 
  fprintf(fid3,'\n   correlation =%7.3f',mx);
  fclose(fid3);
 end
end
fclose(fid);
