function e = ipialehp_trc
%
%function to create the cell array necessary to run TRACE in
%MATLAB. 
%the input for TRACE is a cell array e of size [n 4]. n is the number of 
%series and 4 is the number of fields that contain the information for 
%each series
%e{i,1} contains the title of the series
%e{i,2} contains the number of observations, the initial year, the
%       initial period and control number, see pp. 24 and 25 of TRACE
%       manual
%e{i,3} contains the series path or the series itself
%e{i,4} contains the namelist input 


name='ipitrend';                                 %series name for TRACE
st='336 1950 1 2';     %NZ NYER NPER NFILE on page 24 of the TRACE manual


ppath=cd;      %Current path. For example, C:\tst\spectrc
%Now, obtain path for the programs (ppath). For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrc'); ppath=ppath(1:x-1);
%alternatively
% ppath='C:\tst';


freq='12';                                       %series frequency
spec='di=2 lambda=127864.652';                   %HP filter 
input=['filter=1 method=1 graph=1 mfrec=' freq];
%the filter is applied without a model for the input series. 

e{1,1}=name;                                     
e{1,2}=st;   
%path for the data, according to NFILE above. In this case, the data will 
%be read from the GRAPH directory because NFILE=2. 
e{1,3}=[' ' ppath '\graph\series\trendo.t'];   

input=[input ' ' spec]; 
e{1,4}=input;
