function c = IPIUS_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.


%load data
data=xlsread('c:\tst\series\FINAL_CKZ_JAE2.xls'); 

data=data(76:end,:);       %data starts at 1953.M4


%series title
title='IPIus';          %remove blanks 

%initial year, initial period
inyinp='1953 4';

%read data
y=data(:,2);  

[ny,my]=size(y);

nobs=num2str(ny);
nnobs=length(nobs);     %string

if nnobs < 5
 nobs=[nobs blanks(5-nnobs)];
end
c{1,1}=title;
c{1,2}=[nobs ' ' inyinp];
c{1,3}=y;   

%-------------------------------------------------------------
%instructions for TRAMO/SEATS

%          TRAMO
% MQ   : number of observations per year
% IDIF : way of the model identification (e.g. automatic)
% INIC : way of the model identification 
% LAM  : logs versus level specification 
% IATIP: outlier detection and correction
% IMVX : estimation method, especially relevant in the outlier detection
% and correction

input=' mq=12 idif=3 inic=3 lam=1 iatip=1 imvx=1 '; 

%         SEATS
% SEATS : create input file for SEATS or not
% RMOD  : cutting point for the modulus of an AR root
% EPSPHI: assign the portion of a complex root of the regular polynomial to
% the seasonal

% input=[input ' seats=2 rmod=0 epsphi=0'];

d{1,1}=input;                                   %namelist input
c{1,4}=d;

