function c = PV_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

c=[];
%read data from excel spreadsheet. The first column contains the dates.
[data,titles]=xlsread('c:\tst\series\VIVIUSA');  
data=data(:,1:8);

%eliminate NaNs
data(any(isnan(data)'),:) = [];

pv=[data(:,3) data(:,5)];
titlesv=titles(1,[4,6]);

for i=1:2
 %series title
 title=titlesv(i); 
 %initial year, initial period
 inyinp='1980 1';
 %read data
 y=pv(:,i); 
 [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=char(title); 
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
input='lam=-1 idif=3 inic=3 itrad=-1 ieast=-1 iatip=1 imvx=1 seats=2 '; 
input=[input ' iter=3'];
 d{1,1}=input;                                   %namelist input
 c{i,4}=d;
end


