function c = afconsnc_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

c=[];

%series title
title='afconsnc'; 
%initial year, initial period
inyinp='1985 1';
%data
ppath=cd;      %Current path. For example, C:\tst\spectrm
%Now, obtain path for the programs. For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrm'); ppath=ppath(1:x-1); 
y=load([ppath '\series\afconsnc.dat']); [ny,my]=size(y);


nobs=num2str(ny); nnobs=length(nobs);     %string
if nnobs < 5
 nobs=[nobs blanks(5-nnobs)];
end
c{1,1}=title;
c{1,2}=[nobs ' ' inyinp];
c{1,3}=y;              
%instructions for TRAMO/SEATS
input='lam=-1 idif=2 imean=0 inic=3 itrad=-1 ieast=-1 iatip=1 seats=2 va=3.2 '; 
input=[input ' imvx=1  mq=12 rmod=0 epsphi=180 ireg=9 '];             
d{1,1}=input;                                   %namelist input
% d{1,2}='iuser=2 nser=12 ';                      %variables para plan e
% d{1,3}='289 ao 290 ao 291 ao 292 ao 293 ao 294 ao 295 ao 296 ao 297 ao 298 ao 299 ao 300 ao ';
d{1,2}='iuser=2 nser=9 ';                      %variables para plan e
d{1,3}='291 ao 293 ao 294 ao 295 ao 296 ao 297 ao 298 ao 299 ao 300 ao';
% d{1,2}='iseq=1 ';                      %variables para plan e 2009
% d{1,3}='293 4 ';
% d{1,4}='iseq=1 delta=.8828';                      %variables para plan e 2009
% d{1,5}='245 1 ';
% d{1,6}='iseq=1 ';                      %variables para plan e 2010
% d{1,7}='305 4 ';
% d{1,8}='iseq=1 ';                      %variables para plan e 2010
% d{1,9}='309 4 ';
c{1,4}=d;


