function c = ccaacons_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

c=[];
%read data from excel spreadsheet. The first column contains the dates.
[data,header]=xlsread('c:\tst\series\Construccion');



%all strings in the list should have the same length
%header(1,:) contains the names of the series. The first name is a blank. 
list=strvcat(header(1,2:end));
[n,m]=size(list);


%data directory. For example, C:\tst\series
ppath=cd;      %Current path. For example, C:\tst\spectrm
%Now, obtain path for the programs. For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrm'); ppath=ppath(1:x-1); 
%alternatively
% ppath='C:\tst';


for i=1:n
 %series title
 title=list(i,1:3); if i == n, title='TOT'; end
 %initial year, initial period
 inyinp='2007 1';
 %read data
 y=data(:,i);  
 [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=title;
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
 input='lam=-1 imean=0 itrad=-1 ieast=-1 iatip=1 seats=2 iter=3'; 
 input=[input ' aio=1 imvx=1 mq=12 rmod=0 epsphi=180 ireg=4 '];             
 d{1,1}=input;                                   %namelist input
 d{1,2}='iuser=2 nser=1 ';                       %variables para plan e
 d{1,3}='37 ls ';
 d{1,4}='iseq=1 ';                       %variables para plan e 2009
 d{1,5}='25 4 ';
 d{1,6}='iseq=1 ';                       %variables para plan e 2009
 d{1,7}='29 4 ';
 d{1,8}='iseq=1 ';                       %variables para plan e 2009
 d{1,9}='33 4 ';
 c{i,4}=d;
end

