function c = epaccaaagr_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

c=[];
%read data from excel spreadsheet. The first column contains the dates.
hoja='con';                      %agr, con, ind, ser
[data,header]=xlsread('c:\tst\series\epaccaa',hoja);



%all strings in the list should have the same length
%header(1,:) contains the names of the series. The first name is a blank. 
list=strvcat(header(1,2:end));
[n,m]=size(list);


%data directory. For example, C:\tst\series
ppath=cd;      %Current path. For example, C:\tst\spectrm
%Now, obtain path for the programs. For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrm'); ppath=ppath(1:x-1); 
%alternatively
% ppath='C:\tst';

ytotal=zeros(size(data(:,1)));

for i=1:n
 %series title
 title=list(i,:); 
 %initial year, initial period
 inyinp='1995 1';
 %read data
 y=data(:,i); 
 ytotal=ytotal+y;
 [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=title;
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
 input='lam=-1 idif=3 inic=3 itrad=-1 ieast=-1 iatip=1 seats=2 iter=3'; 
 input=[input ' aio=1 mq=4 rmod=0 epsphi=180 ireg=4 '];             
 d{1,1}=input;                                   %namelist input
 d{1,2}='iuser=2 nser=4 ';                       %variables para plan e
 d{1,3}='57 ao 58 ao 59 ao 60 ao ';
 c{i,4}=d;
end
%total
c{n+1,1}='Total';
c{n+1,2}=[nobs ' ' inyinp];
c{n+1,3}=ytotal;
input='lam=-1 idif=3 inic=3 itrad=-1 ieast=-1 iatip=1 seats=2 iter=3'; 
input=[input ' aio=1 mq=4 rmod=0 epsphi=180 ireg=4 '];             
d{1,1}=input;                                   %namelist input
d{1,2}='iuser=2 nser=4 ';                       %variables para plan e
d{1,3}='57 ao 58 ao 59 ao 60 ao ';
c{n+1,4}=d;


