function c = examp20_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.


%all strings in the lists should have the same length
list1=['CAR-REGR'               
       'QUAT-CAR'
      ];
[n,m]=size(list1);
list2=['1971 1'
       '1971 1'
       ];
list3=['rsa=3 iter=3'
       'mq=4 rsa=3  '
      ];
     
%data directory. For example, C:\tst\series
ppath=cd;      %Current path. For example, C:\tst\spectrm
%Now, obtain path for the programs. For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrm'); ppath=ppath(1:x-1); 

for i=1:n
 %series title
 title=list1(i,:); 
 c{i,1}=title;
 %initial year, initial period
 inyinp=list2(i,:);
 %read data
 y=load([ppath '\series\' title '.dat']); 
 %transform table into column
 y=y'; y=y(:);
% number of observations
 [ny,my]=size(y);                          %number
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,2}=[nobs ' ' inyinp];  
 c{i,3}=y;
 %instructions for TRAMO/SEATS
 input=list3(i,:); 
 d{1,1}=input;                                   %namelist input
 c{i,4}=d;
end
