function c = gerprcwgw_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

%series names
list={'PRGer'
      'CWGer' 
      'GWGer'};
[n,m]=size(list);

%load data
data=xlsread('c:\tst\series\PROJECT_GER_IND_RAW'); 


for i=1:n
 %series title
 title=list{i};          %remove blanks 
 %initial year, initial period
 inyinp='1970 1';
 %read data
 y=data(:,i);  [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=title;
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
 input='mq=4 idif=3 inic=3 lam=1 iatip=1 imvx=1 iter=3'; 
 input=[input ' seats=2 rmod=0 epsphi=180'];
 d{1,1}=input;                                   %namelist input
 c{i,4}=d;
end
