function c = simul_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

c=[];
%read data.
file='z3m1t5n3mod7'; 
path='c:\MATLAB\R2008b\MIAS\uroot\simul\';
data=load([path file]);

nstda=str2double(file(2)); stda=[];
if nstda == 1
 stda=.005;
elseif nstda == 2
 stda=.05; 
elseif nstda == 3
 stda=1.;
elseif nstda == 4
 stda=100.; 
elseif nstda == 5
 stda=1000.; 
elseif nstda == 6
 stda=.15; 
end

nN=str2double(file(6)); N=[];
if nN == 0
 N=30;
elseif nN == 1
 N=50;
elseif nN == 2
 N=100;
elseif nN == 3
 N=150;
elseif nN == 4
 N=200;
elseif nN == 5
 N=500;
end

nNs=str2double(file(8)); Ns=[];
if nNs == 1 
 Ns=100;
elseif nNs == 2 
 Ns=1000;
elseif nNs == 3 
 Ns=20000;
end

for i=1:Ns
 %series title
 title=['s' num2str(i)];  
 %initial year, initial period
 inyinp='1 1';
 %read data
 y=data((i-1)*N+1:i*N);  
 [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=title;
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
 input='lam=1 idif=1 inic=3 mq=1 out=2 iter=3'; 
 d{1,1}=input;                                   %namelist input
 c{i,4}=d;
end

