function c = xss_trm
%
%function to create the cell array necessary to run TRAMO/SEATS in
%MATLAB. 
%The input for TRAMO is a cell array c of size [n m]. n is the number of 
%series and m is the number of fields that contain the information for 
%each series
%c{i,1} contains the title of the series
%c{i,2} contains the number of observations, the initial year and the
%       initial period
%c{i,3} contains the series
%c{i,4} an optional field. It is a cell array, d, that contains the
%       namelist input and optional additional namelists reg and 
%       instructions for these last namelists.
%       namelists reg, if any, and the corresponding data should be written
%       in pairs.

[data,header]=xlsread('c:\tst\series\XMK');

data=data(230:end,:);       %data starts at 2000-1.
data=log(data);
s=5;

%export series
xseries=data(:,1:s);

%all strings in the list should have the same length
%header(1,:) contains the names of the series. The first name is a blank. 
list=strvcat(header(1,2:6));
[n,m]=size(list);


%data directory. For example, C:\tst\series
ppath=cd;      %Current path. For example, C:\tst\spectrm
%Now, obtain path for the programs. For example, C:\tst
ppath=lower(ppath); x=strfind(ppath,'\spectrm'); ppath=ppath(1:x-1); 
%alternatively
% ppath='C:\tst';

for i=1:n
 %series title
 title=list(i,:); 
 %initial year, initial period
 inyinp='2000 1';
 %read data
 y=xseries(:,i); 
 [ny,my]=size(y);
 nobs=num2str(ny); nnobs=length(nobs);     %string
 if nnobs < 5
  nobs=[nobs blanks(5-nnobs)];
 end
 c{i,1}=title;
 c{i,2}=[nobs ' ' inyinp];
 c{i,3}=y;              
 %instructions for TRAMO/SEATS
 input='lam=-1 idif=3 inic=3 itrad=-1 ieast=-1 iatip=1 seats=2 iter=3'; 
 input=[input ' rmod=0 epsphi=180'];             
 d{1,1}=input;                                   %namelist input
 c{i,4}=d;
end
