function outts = tsmatlab(c,path)
%
% MATLAB program to run TS (Tramo/Seats)
%
% Input parameters: 
%      c: a cell-array containing the information to run TS
%   path: a string containing the path where TSTMATLAB is located
% Output parameters:
%  outts: a structure containing the output of TS               
%
% Copyright (c) November 2009 by Victor Gomez
% Ministerio de Hacienda, Direccion Gral. de Presupuestos, 
% Subdireccion Gral. de Analisis y P.E., 
% Alberto Alcocer 2, 1-P, D-34, 28046, Madrid, SPAIN.
% Phone : +34-915835439
% E-mail: vgomez@sepg.minhac.es
%
% The author assumes no responsibility for errors or damage resulting from the use
% of this code. Usage of this code in applications and/or alterations of it should 
% be referenced. This code may be redistributed if nothing has been added or
% removed and no money is charged. Positive or negative feedback would be appreciated.
%

outts=[];

[n,m]=size(c);

fout=0; fseats=0;
if n > 1
 for i=1:n
  if ~isempty(c{i,4})
   cc{1,1}=c{i,1}; cc{1,2}=c{i,2}; cc{1,3}=c{i,3}; cc{1,4}=c{i,4};
   out{i} = inputval(cc,'out');
   ireg{i} = inputval(cc,'ireg');
   %with 'out=-2 ' TRAMO produces the files TABLE.TRM, NUMRES1.TRM NUMRES2.TRM
   if isempty(out{i})
    aa=cc{1,4}; a=aa{1,1}; 
    a=[a ' out=-2'];
    aa{1,1}=a;  c{i,4}=aa;
    fout=1;
   elseif abs(out{i}) == 2
    fout=1;
   end
   seats = inputval(cc,'seats');   
   if (seats > 0) 
    fseats = 1;
   end
   rsa = inputval(cc,'rsa');
   if (rsa > 0) 
    fseats = 1;
   end
  end
 end
else
 if ~isempty(c{1,4})
  out = inputval(c,'out');
  ireg = inputval(c,'ireg');
  %with 'out=-2 ' TRAMO produces the files TABLE.TRM, NUMRES1.TRM NUMRES2.TRM
  if isempty(out)
   aa=c{1,4}; a=aa{1,1}; 
   a=[a ' out=-2'];
   aa{1,1}=a;  c{1,4}=aa;
   fout=1;
  elseif abs(out) == 2
   fout=1;
  end
  seats = inputval(c,'seats');
  if (seats > 0)  
   fseats = 1;
  end
  rsa = inputval(c,'rsa');
  if (rsa > 0) 
   fseats = 1;
  end
 end
end

%create serie.trm file for TRAMO/SEATS
wrsertrm(c);

%run TS programs
delete('graph\acf\*.*');
delete('graph\forecast\*.*');
delete('graph\filters\*.*');
delete('graph\regoutse\*.*');
delete('graph\series\*.*');
delete('graph\spectra\*.*');

! copy serie.trm serie
% ! main antiguo, .trm. main nuevo, .out
! main 
if fseats == 1
 ! copy seats.itr serie
 ! analts
end

modelinf=[];
if fout == 1
%  modelinf=load([path '\output\numres1.trm']); 
 modelinf=load([path '\output\numres1.trm']); 
 modelinf2=load([path '\output\numres2.trm']); 
end


%store results in structure outtst
if n > 1
 for i=1:n
  title=c{i,1};
  [n,m]=size(title); 
  if m > 8
   title=title(1:8);
  end
  outts(i).title=title;                      %title
  nziyip=str2num(c{i,2});
  outts(i).nziyip=nziyip;                    %number of observ., etc.
  ser=c{i,3};
  outts(i).orig=ser;                         %original series
  if ~isempty(modelinf)
   outts(i).model.lamda=modelinf(i,4);
   outts(i).model.imean=modelinf(i,5);
   outts(i).model.itrad=modelinf(i,6);
   outts(i).model.ieast=modelinf(i,7);
   if ~isempty(ireg{i})
    outts(i).model.ireg=ireg{i};
   end
   p=modelinf(i,8);
   q=modelinf(i,10);
   bp=modelinf(i,11);
   bq=modelinf(i,13);
   nao=modelinf(i,14);
   ntc=modelinf(i,15);
   nls=modelinf(i,16);
   outts(i).model.p=p;
   outts(i).model.d=modelinf(i,9);
   outts(i).model.q=q;
   outts(i).model.bp=bp;
   outts(i).model.bd=modelinf(i,12);
   outts(i).model.bq=bq;
   if nao > 0
    outts(i).model.nao=nao;
   end
   if ntc > 0
    outts(i).model.ntc=ntc;
   end
   if nls > 0
    outts(i).model.nls=nls;
   end
   outts(i).model.residst=modelinf(i,17);
   outts(i).model.pvbox=modelinf(i,18);
   outts(i).model.pvnt=modelinf(i,19);
   if p > 0
    outts(i).model.phi=modelinf2(i,2:1+p);
   end
   if bp > 0
    outts(i).model.bphi=modelinf2(i,5);
   end
   if q > 0
    outts(i).model.th=modelinf2(i,6:5+q);
   end
   if bq > 0
    outts(i).model.bth=modelinf2(i,9);
   end
  end
  %en main.exe es la siguiente linea
%   mpath=[path '\graph\series\' title '. lin']; at=fileattrib(mpath);
  mpath=[path '\graph\series\' title '.lin']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath); 
   outts(i).lin=str.data; 
   outts(i).model.freq=str2num(str.freq);
  end
  mpath=[path '\graph\series\' title '.tre']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   outts(i).tre=str.data;
   outts(i).model.freq=str2num(str.freq);   
  end
  mpath=[path '\graph\series\' title '.sa']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   outts(i).sa=str.data;
   outts(i).model.freq=str2num(str.freq);
  end
  mpath=[path '\graph\forecast\' title '.fx']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   outts(i).fx=str.data;
  end
  mpath=[path '\graph\forecast\' title '.ftr']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   outts(i).ftr=str.data;
  end
  mpath=[path '\graph\forecast\' title '.fsa']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   outts(i).fsa=str.data;
  end
  mpath=[path '\graph\forecast\' title '.ftx']; at=fileattrib(mpath);
  if at
   str = readgraphfilep(mpath);
   outts(i).ftx=str.data;
  end
 end
else
 title=c{1,1};
 outts(1).title=title;                      %title
 nziyip=str2num(c{1,2}); 
 outts(1).nziyip=nziyip;                    %number of observ., etc.
 ser=c{1,3};
 outts(1).orig=ser;                         %original series
  if ~isempty(modelinf)
   outts(1).model.lamda=modelinf(1,4);
   outts(1).model.imean=modelinf(1,5);
   outts(1).model.itrad=modelinf(1,6);
   outts(1).model.ieast=modelinf(1,7);
   if ~isempty(ireg)
    outts(1).model.ireg=ireg;
   end
   p=modelinf(1,8);
   q=modelinf(1,10);
   bp=modelinf(1,11);
   bq=modelinf(1,13);
   nao=modelinf(1,14);
   ntc=modelinf(1,15);
   nls=modelinf(1,16);
   outts(1).model.p=p;
   outts(1).model.d=modelinf(1,9);
   outts(1).model.q=q;
   outts(1).model.bp=bp;
   outts(1).model.bd=modelinf(1,12);
   outts(1).model.bq=bq;
   if nao > 0
    outts(1).model.nao=nao;
   end
   if ntc > 0
    outts(1).model.ntc=ntc;
   end
   if nls > 0
    outts(1).model.nls=nls;
   end
   outts(1).model.residst=modelinf(1,17);
   outts(1).model.pvbox=modelinf(1,18);
   outts(1).model.pvnt=modelinf(1,19);
   if p > 0
    outts(1).model.phi=modelinf2(1,2:1+p);
   end
   if bp > 0
    outts(1).model.bphi=modelinf2(1,5);
   end
   if q > 0
    outts(1).model.th=modelinf2(1,6:5+q);
   end
   if bq > 0
    outts(1).model.bth=modelinf2(1,9);
   end
  end
 mpath=[path '\graph\series\differ.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.differ=str.data;
 end
 mpath=[path '\graph\series\growt.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.growt=str.data;
 end
 mpath=[path '\graph\series\gserie.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.gserie=str.data;
 end
 mpath=[path '\graph\series\irreg.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.irreg=str.data;
 end
 mpath=[path '\graph\series\irregfac.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.irregfac=str.data;
 end
 mpath=[path '\graph\series\paeasf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.paeasf=str.data;
 end
 mpath=[path '\graph\series\paotrf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.paotrf=str.data;
 end
 mpath=[path '\graph\series\paeasf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.paeasf=str.data;
 end
 mpath=[path '\graph\series\patdf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.patdf=str.data;
 end
 mpath=[path '\graph\series\pisa.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.pisa=str.data;
 end
 mpath=[path '\graph\series\piseas.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.piseas=str.data;
 end
 mpath=[path '\graph\series\pitrend.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.pitrend=str.data;
 end
 mpath=[path '\graph\series\preadc.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.preadc=str.data;
 end
 mpath=[path '\graph\series\preadf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.preadf=str.data;
 end
 mpath=[path '\graph\series\residt.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.residt=str.data; 
  outts(1).model.freq=str2num(str.freq);
 end
 mpath=[path '\graph\series\rserie.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.rserie=str.data;
 end
 mpath=[path '\graph\series\safin.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.safin=str.data;
 end
 mpath=[path '\graph\series\sarate.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.sarate=str.data;
 end
 mpath=[path '\graph\series\seas.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.seas=str.data;
 end
 mpath=[path '\graph\series\seasadjo.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.seasadjo=str.data;
 end
 mpath=[path '\graph\series\seasadjt.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.seasadjt=str.data;
 end
 mpath=[path '\graph\series\seasfac.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.seasfac=str.data;
 end
 mpath=[path '\graph\series\serie.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.serie=str.data; 
 end
 mpath=[path '\graph\series\sfin.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.sfin=str.data;
 end
 mpath=[path '\graph\series\spregf.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.spregf=str.data;
 end
 mpath=[path '\graph\series\trate.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.trate=str.data;
 end
 mpath=[path '\graph\series\trendo.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.trendo=str.data;
 end
 mpath=[path '\graph\series\trendot.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.trendot=str.data;
 end
 mpath=[path '\graph\series\trendt.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.trendt=str.data;
 end
 mpath=[path '\graph\series\trfin.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.trfin=str.data;
 end
 mpath=[path '\graph\series\tserie.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.tserie=str.data;
 end
 mpath=[path '\graph\series\xcetd.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.xcetd=str.data;
 end
 mpath=[path '\graph\series\xcout.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.xcout=str.data;
 end
 mpath=[path '\graph\series\xcreg.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.xcreg=str.data;
 end
 mpath=[path '\graph\series\xint.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.xint=str.data;
 end
%there is an error in this version of TRAMO for the xlin series. There is
%in the input file one extra blank line in the third line.
 mpath=[path '\graph\series\xlin.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).series.xlin=str.data(2:end);
 end
 cont=0;
 while 1
  cont=cont+1; st=num2str(cont);
  mpath=[path '\graph\regoutse\reg' st  '.t']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   eval(['outts(1).regoutse.reg' st '=str.data;']);
  else
   break
  end
 end
 mpath=[path '\graph\regoutse\regsum.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.regsum=str.data;
 end
 cont=0;
 while 1
  cont=cont+1; st=num2str(cont);
  mpath=[path '\graph\regoutse\trad' st  '.t']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   eval(['outts(1).regoutse.trad' st '=str.data;']);
  else
   break
  end
 end
 mpath=[path '\graph\regoutse\tradsum.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.tradsum=str.data;
 end
 mpath=[path '\graph\regoutse\etdsum.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.etdsum=str.data;
 end
 mpath=[path '\graph\regoutse\east.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.east=str.data;
 end
 cont=0;
 while 1
  cont=cont+1; st=num2str(cont);
  mpath=[path '\graph\regoutse\outl' st  '.t']; at=fileattrib(mpath);
  if at
   str = readgraphfile(mpath);
   eval(['outts(1).regoutse.outl' st '=str.data;']);
  else
   break
  end
 end
 mpath=[path '\graph\regoutse\outsum.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.outsum=str.data;
 end
 mpath=[path '\graph\regoutse\totrose.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).regoutse.totrose=str.data;
 end
%  mpath=[path '\graph\forecast\forx.t5']; at=fileattrib(mpath); 
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.forx=str.data;
%  end
%  mpath=[path '\graph\forecast\forxl.t5']; at=fileattrib(mpath);
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.forxl=str.data;
%  end
%  mpath=[path '\graph\forecast\fort.t5']; at=fileattrib(mpath);
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.fort=str.data;
%  end
%  mpath=[path '\graph\forecast\fortc.t5']; at=fileattrib(mpath);
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.fortc=str.data;
%  end
%  mpath=[path '\graph\forecast\forsf.t5']; at=fileattrib(mpath);
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.forsf=str.data;
%  end
%  mpath=[path '\graph\forecast\forsc.t']; at=fileattrib(mpath);
%  if at
%   str = readgraphfile(mpath);
%   outts(1).forecast.forsc=str.data;
%  end
 mpath=[path '\graph\forecast\fdetf.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.fdetf=str.data;
 end
 mpath=[path '\graph\forecast\freg.t']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.freg=str.data;
 end
 mpath=[path '\graph\forecast\fsafin.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.fsafin=str.data;
 end
 mpath=[path '\graph\forecast\fsfin.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.fsfin=str.data;
 end
 mpath=[path '\graph\forecast\ftrfin.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.ftrfin=str.data;
 end
 mpath=[path '\graph\forecast\funorig.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.funorig=str.data;
 end
 mpath=[path '\graph\forecast\pred.t6']; at=fileattrib(mpath); 
 if at
  str = readgraphfilep(mpath);
  outts(1).forecast.pred=str.data;
 end
 mpath=[path '\graph\forecast\predl.t6']; at=fileattrib(mpath); 
 if at
  str = readgraphfilep(mpath);
  outts(1).forecast.predl=str.data;
 end
 mpath=[path '\graph\forecast\spreg.t5']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).forecast.spreg=str.data;
 end
 mpath=[path '\graph\acf\auto.t2']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).acf.auto=str.data;
 end
 mpath=[path '\graph\acf\dautot.t2']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).acf.dautot=str.data;
 end
 mpath=[path '\graph\acf\dauto.t2']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).acf.dauto=str.data;
 end
 mpath=[path '\graph\acf\pauto.t2']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).acf.pauto=str.data;
 end
 mpath=[path '\graph\spectra\spect.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spect=str.data;
 end
 mpath=[path '\graph\spectra\spectt.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectt=str.data;
 end
 mpath=[path '\graph\spectra\spectet.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectet=str.data;
 end
 mpath=[path '\graph\spectra\spectsa.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectsa=str.data;
 end
 mpath=[path '\graph\spectra\spectesa.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectesa=str.data;
 end
 mpath=[path '\graph\spectra\spects.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spects=str.data;
 end
 mpath=[path '\graph\spectra\spectes.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectes=str.data;
 end
 mpath=[path '\graph\spectra\spectsa.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectsa=str.data;
 end
 mpath=[path '\graph\spectra\spectesa.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectesa=str.data;
 end
 mpath=[path '\graph\spectra\spectei.t3']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).spectra.spectei=str.data;
 end
 mpath=[path '\graph\filters\filtft.t4f']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtft=str.data;
 end
 mpath=[path '\graph\filters\filtfs.t4f']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtfs=str.data;
 end
 mpath=[path '\graph\filters\filtfi.t4f']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtfi=str.data;
 end
 mpath=[path '\graph\filters\filtfadj.t4f']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtfadj=str.data;
 end
 mpath=[path '\graph\filters\filtadj.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtadj=str.data;
 end
 mpath=[path '\graph\filters\filti.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filti=str.data;
 end
 mpath=[path '\graph\filters\filts.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filts=str.data;
 end
 mpath=[path '\graph\filters\filtt.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.filtt=str.data;
 end
 mpath=[path '\graph\filters\psisa.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.psisa=str.data;
 end
 mpath=[path '\graph\filters\psiseas.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.psiseas=str.data;
 end
 mpath=[path '\graph\filters\psitre.t4']; at=fileattrib(mpath);
 if at
  str = readgraphfile(mpath);
  outts(1).filters.psitre=str.data;
 end
end
